@@ -3,7 +3,6 @@ check_input_data_splitting <- function(error_message,
                                        check_values,
                                        split_prop,
                                        nsplits,
-                                       parallel,
                                        ncores,
                                        raw_output,
                                        ...) {
@@ -14,8 +13,6 @@ check_input_data_splitting <- function(error_message,
       error_message <- paste(error_message, "split_prop is not numeric.", sep = "\n")
     if (!is.numeric(nsplits))
       error_message <- paste(error_message, "nsplits is not numeric.", sep = "\n")
-    if (!is.character(parallel))
-      error_message <- paste(error_message, "parallel is not character.", sep = "\n")
     if (!is.numeric(ncores))
       error_message <- paste(error_message, "ncores is not numeric.", sep = "\n")
     if (!is.logical(raw_output) & !is.null(raw_output))
@@ -26,9 +23,6 @@ check_input_data_splitting <- function(error_message,
       error_message <- paste(error_message, "split_prop is not in (0, 1).", sep = "\n")
     if (nsplits < 1)
       error_message <- paste(error_message, "nsplits cannot be smaller than 1.", sep = "\n")
-    if (!(parallel %in% c("no", "multicore", "snow")))
-      error_message <- paste(error_message, "No valid parallelization method
-                           selected. Choose either 'no', 'multicore' or 'snow'.", sep = "\n")
     if (ncores < 1)
       error_message <- paste(error_message, "ncores cannot be smaller than 1.", sep = "\n")
     return(error_message)
